#ifndef NT2_INCLUDE_FUNCTIONS_NBTRUE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NBTRUE_HPP_INCLUDED

#include <nt2/reduction/include/functions/nbtrue.hpp>

#endif
